#
# spec file for package gnome-tweak-tool
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Luis Medinas, Lisbon, Portugal.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-tweak-tool
Version:        3.26.4
Release:        2.40
Summary:        A tool to customize advanced GNOME 3 options
License:        GPL-3.0+
Group:          System/GUI/GNOME
Url:            http://live.gnome.org/GnomeTweakTool
Source0:        http://download.gnome.org/sources/gnome-tweak-tool/3.26/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
# Needed to have typelib() Requires
BuildRequires:  gobject-introspection
# Needed for icon_theme_cache_* macros and file ownership.
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.23.3
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.10
Requires:       gnome-shell >= 3.24
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-xml
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%if !0%{?is_opensuse}
BuildRequires:  translation-update-upstream
%endif

%description
GNOME Tweak Tool is an application for changing the advanced settings
of GNOME 3.

%lang_package

%prep
%setup -q
%if !0%{?is_opensuse}
translation-update-upstream
%endif
# Tiny tweak to shut up rpmlint
sed -i 's:Pantheon:X-Pantheon:g' */gnome-tweak-tool.desktop.in
# Tweak to fix python env
sed -i "s|#!/usr/bin/env python3|#!%{_bindir}/python3|g" %{name}*

%build
%meson
%meson_build

%install
%meson_install
# FIXME Drop traces of buildroot
rm -rf %{buildroot}/%{python3_sitelib}/gtweak/__pycache__/*.pyc
rm -rf %{buildroot}/%{python3_sitelib}/gtweak/tweaks/__pycache__/*.pyc
%suse_update_desktop_file %{name} X-GNOME-PersonalSettings
%fdupes %{buildroot}%{_datadir}/gnome-tweak-tool/
%fdupes %{buildroot}%{python_sitelib}
%find_lang %{name} %{?no_lang_C}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README
%{_bindir}/%{name}
%{python3_sitelib}/gtweak/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/gnome-tweak-tool.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_libexecdir}/gnome-tweak-tool-lid-inhibitor

%files lang -f %{name}.lang

%changelog
* Fri Dec 29 2017 zaitor@opensuse.org
- Drop obsolete and unused pkgconfig(gconf-2.0) BuildRequires:
  Dropped upstream years ago.
* Thu Dec 14 2017 zaitor@opensuse.org
- Update to version 3.26.4:
  + Stop requiring a GTK2 theme for Applications theme switcher.
  + Offer HighContrastInverse theme.
  + Don't show duplicate theme names.
  + Updated translations.
- Add sed hack to replace the "/usr/bin/env python3" hashbang with
  "/usr/bin/python3" in the scripts to be installed.
* Thu Nov  2 2017 fezhang@suse.com
- Update to version 3.26.3:
  + Updated translations.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.2.1:
  + Don't offer emoji support in search boxes.
  + Updated translations.
* Thu Sep 21 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + New bugfix release:
  - Fix enabling and disabling GNOME Shell extensions.
  - Fix Workspace tweaks in GNOME Shell and "modes".
  - Hide Workspaces panel if GNOME Shell isn't running.
  - Add "Activities Overview Hot Corner" tweak. This is disabled
    by default because it requires a patch from bgo#688320 that
    hasn't been committed yet.
  + Updated translations.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Fix linking to GNOME Software from Extensions page.
  + Note that gnome-shell schemas >= 3.24 are required.
  + Updated translations.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Don't add appmenu to windows buttons if it's already there.
  + Prompt to log out when changing Application Menu setting.
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90.1:
  + Fix vertical scrollbar placement.
  + Restore redesigned Window Focus Mode listbox.
- Changes from version 3.25.90:
  + Remove Power Button setting; this feature is now in
    gnome-control-center 3.25.90+.
  + Don't show HiDPI setting; use gnome-control-center 3.25.90+
    instead.
  + Revert Focus Mode list box to 3.24 combobox to eliminate
    vertical scrolling.
  + Rename /usr/bin/gnome-tweaks back to /usr/bin/gnome-tweak-tool.
  + Add '--version' option to /usr/bin/gnome-tweak-tool.
  + Make notification string translatable.
  + Updated translations.
* Wed Jul 19 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Rename app to GNOME Tweaks.
  + Rename binary to gnome-tweaks.
  + Only allows numbers in Hi-DPI entry box.
  + Updated translations.
- Changes from version 3.25.3:
  + Move Typing panel to Additional Layout Options dialog in
    Keyboard & Mouse.
  + Move Compose Key setting to Keyboard & Mouse dialog.
  + Convert some settings to ListBoxes.
  + Several other UI tweaks to match Design Team mockup.
  + Only show Top Bar page and Overview Shortcut if GNOME Shell is
    running.
  + Enable 'appmenu' window button when disabling App Menu.
  + Use Ubuntu sort order for Left placement of window buttons.
  + Fix "blank slate" for Extensions page.
  + Drop build-time checks for run-time dependencies.
  + Distributors, please see README for run-time dependencies
  + Consistently use /usr/bin/env python3 shebangs.
  + Rewrite post-install script in Python.
  + Handle SIGINT (Ctrl+C).
- Drop post(un) handling of icon_theme_cache_post(un), no longer
  needed as we have file-triggers taking care of this for us now.
- Tweak .desktop file with sed replacement to quiet rpmlint.
* Mon Jun 12 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Add "Battery Percentage" tweak.
  + Add "Disable While Typing" tweak.
  + Add Left/Right Placement tweak for window buttons.
  + Update About to show Tweak Tool and GTK+ versions.
  + Add "blank slate" for Extensions page.
  + Remove support for installing and uninstalling extensions since
    GNOME Software handles this since 3.22.
  + Other UI tweaks to Extensions page.
  + Many UI tweaks suggested by Allan Day.
  + Misc code cleanup.
  + Use Unicode in translatable strings.
  + Create config directories as necessary.
  + Install appstream metadata to /usr/share/metainfo/.
  + Switch from python2 to python3.
  + Switch from autotools to meson.
  + Drop intltool dependency.
  + Updated translations.
- Drop intltool BuildRequires: Following upstream changes.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Replace python-gobject, python-gobject-Gdk and python-xml with
  python3-gobject, python3-gobject-Gdk and python3-xml Requires
  following upstreams port to python3.
- Drop %%py_requires: no longer needed with python3.
* Mon Jun 12 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Fix search.
  + Fix running Tweak Tool if GNOME Shell is not running.
  + Only show Top Bar panel if GNOME Shell is running.
  + Create config directories as necessary.
  + Explicitly use python2 shebang.
  + Handle SIGINT.
  + Require gsettings-desktop-schemas 3.23.3+ and pygobject 3.10+.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Add a gnome-shell extensions "kill switch".
  + Make Gtk/EnablePrimaryPaste also configurable on wayland.
  + Updated translations.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Add XKB options that are not in the 3.22 Keyboard panel.
  + Updated translations.
* Mon Sep  5 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Add a mouse acceleration profile tweak.
  + Add a proper title to the main window.
  + Use the new org.gnome.desktop.calendar schema.
  + Fix screenshot link in appdata.
  + Updated translations.
* Mon Aug  8 2016 fezhang@suse.com
- Drop gnome-tweak-tool-bnc898328-remove-lid-action-entries.patch
  (bsc#898328). Original problem fixed upstream and lid action is
  back.
* Mon May 23 2016 cxiong@suse.com
- Update to GNOME 3.20.2 FATE#318572
- Dropped bnc951346-add-sle-classic-schema-overrides-check.patch
  Not needed any more with 3.20-based SLE Classic.
* Tue May  3 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Rebase gnome-tweak-tool-bnc898328-remove-lid-action-entries.patch
* Fri Apr 22 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Support versioned Gtk3 themes.
  + Support multiple selection XKB options.
  + Updated translations.
* Tue Apr 19 2016 dimstar@opensuse.org
- Require python-gobject-Gdk: pygobject was further split in order
  to be able to install it without X-dependencies. As g-t-t is
  a GUI applicartion, the dependency on the X-stack is no issue
  (boo#976069).
* Wed Mar 23 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Reduce the amount of logging we do by default.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Update the AppData file to 0.7+ and add some missing data.
  + Updated translations.
* Mon Jan 18 2016 dimstar@opensuse.org
- Update to version 3.19.1:
  + Restore ‘Power button action’ setting.
  + Use selected font on font selector buttons.
  + Drop dependency on SoupGNOME.
  + Updated translations.
* Tue Dec  1 2015 cxiong@suse.com
- Add bnc951346-add-sle-classic-schema-overrides-check.patch
  (bnc951346). Add sle-classic to the manual overrides checking, so
  configuration through tweak-tools would behave consistently.
* Wed Nov 11 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fixed a crash with some values in the
    org.gnome.desktop.wm.preferences button-layout key.
  + Avoid pygobject unversioned import warnings.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Avoid GSettings aborting when missing classic overrides schema.
  + Startup: Honor disabled user autostart files.
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Add a click method tweak for touchpads.
  + Updated translations.
- Add missing runtime Requires: python-xml.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Several usability improvements in the startup tab and
    application chooser.
  + Provide a symbolic variant of the app icon.
  + Add a way to inhibit systemd's default behavior on lid close.
  + Switch to expanders and radio buttons instead of combo boxes
    for the XKB options.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Several usability improvements in the startup tab and
    application chooser.
  + Provide a symbolic variant of the app icon.
  + Add a way to inhibit systemd's default behavior on lid close.
  + Updated translations.
* Thu Apr 16 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Removed a couple of XKB options that aren't supported in GNOME.
  + Updated translations.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Add "Enable Animations" entry in Appearance group.
  + Make tweak-group and tweak have a transparent background.
  + Use the proper gsetting for "Automatically Raise Windows".
  + Maximize the window on small screens.
  + Take other buttons into account when changing button layout.
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Use the correct default for icon-themes.
  + interface: Remove WindowTheme tweak.
  + Add a confirmation message when changing HiDPI.
  + Change Right/Left super shortcut name.
  + ShellExtension: fix extension prefs button style.
  + Automatically search when unhandled keyboard input is detected.
  + Implemented search functionality for startup applications.
  + Updated translations.
* Wed Dec  3 2014 fezhang@suse.com
- Add gnome-tweak-tool-bnc898328-remove-lid-action-entries.patch
  (bnc#898328). Remove the lid actions from GUI since they are now
  handled by systemd.
* Fri Nov 14 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + startup:
  - Fix check for running executables.
  - Sort application selection list alphabetically.
  + tweakview: Update decorations on settings changes.
  + windows: Stop overriding the Gtk/DecorationLayout xsetting.
  + Remove the use of deprecated properties.
  + Make the window a bit taller.
  + GTK+ required version bump to 3.12.
  + Updated translations.
* Sun Oct  5 2014 zaitor@opensuse.org
- Move .desktopfile from X-GNOME-SystemSettings to
  X-GNOME-PersonalSettings, since the only values one can change is
  for active user. Having it under System gives the impression that
  changes are systemwide.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fix missed function rename, deprecation warnings.
  + Fix some more positional arguments.
  + Updated translations.
* Wed Sep 17 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Disable the menubar.
  + Fix KeyError when extensions with no version are installed.
  + Stop using positional arguments with the GObject constructor
    (bgo#725926).
  + Fix a string that wasn't translated.
  + Updated translations.
* Fri Jun 13 2014 fezhang@suse.com
- Add category X-GNOME-SystemSettings to gnome-tweak-tool.desktop
  so that gnome-control-center can recongnize and show it
  (bnc#866235).
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Add Gdk/WindowScalingFactor tweak.
  + Remove non-functional help menu.
  + Support CSD windows with header bars.
  + Support changing shell overlay keyboard shorcut.
  + Support changing shell lock screen background.
  + Fix CSD header bar.
  + Fix background color of startup apps tab.
  + Fix icon theme detection.
  + Add another digit for font size tweaks.
  + Allow localized searches.
  + More robust startup application handling.
  + Updated translations.
* Tue Nov 12 2013 dimstar@opensuse.org
- Update to version 3.10.1 (bnc#849913):
  + Work around PyGObject bug which caused crashes at startup.
  + Fix detection of themes (bgo#710275).
  + Fix shell extension update checks for stable X.0 releases.
  + Fix startup tweaks for applications missing icons (bgo#708900).
  + Allow localized searches.
  + Fix shell extension error reporting (bgo#711490).
- Drop gnome-tweak-tool-threading-crashes.patch: fixed upstream.
* Tue Oct 22 2013 dimstar@opensuse.org
- Add gnome-tweak-tool-threading-crashes.patch: Fix crashes due to
  threading locks (bnc#846754, bgo#710530).
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Fix appdata file.
  + Updated translations.
* Thu Sep 19 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix CSD decorations.
  + Ship an appdata file.
  + Make titlebar buttons match mockups (more).
  + Startup applications tidy ups.
* Wed Sep  4 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Make titlebar buttons match mockups.
  + Make workspace creation match mockups.
  + Improve search results for gsettings tweaks.
  + Updated translations.
* Thu Aug 22 2013 dimstar@opensuse.org
- Update to version 3.9.90.1:
  + Dont crash when failing to load desktop files.
  + Require GTK 3.9 for ListBox.
- Add pkgconfig(gtk+-3.0) BuildRequires: new verified dependency.
* Thu Aug 22 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Complete UI redesign based on GNOME3.
  + Allow updating extensions from inside tweak tool (bgo#696948).
  + Show text in tooltip when label is ellipsized (bgo#704149).
  + Reluctantly make window resizable (bgo#704149).
  + Specialized ui for certain tweaks.
  + Tweaks can depend on other tweaks being enabled.
  + Add XSettings related tweaks (middle mouse paste, appplication
    menu).
  + Add startup application management.
  + Offer to logout user when tweaks require the session restarted.
  + Better tweak names and descriptions (manage our own
    translations instead of getting all from gsettings).
* Thu Jul 18 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Use extension specific paths to find pref.js (bgo#697685).
  + Dont look in ~/.themes for metacity themes (bgo#693350).
  + Add groups only if they have tweaks (bgo#699572).
  + Work with gnome-shell classic mode (bgo#701760).
* Mon Apr  8 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Fix manual extension installation.
  + Add tweak for window raise-on-click (bgo#696890)
  + Don't crash if gnome-shell is not running/installed
    (bgo#696683)
  + List extensions alphabetically (bgo#695170).
  + Allow uninstalling / deleting extensions (bgo#695983).
  + Show all XKB options except the ones in control center
    (bgo#691381)
  + Fix g-t-t running in classic mode (bgo#694808).
  + Updated translations.
* Fri Mar 15 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Find a theme from XDG base directory spec (bgo#688028).
  + Add keywords to the .desktop file (bgo#687949).
  + Honor different gnome-shell modes on relevant tweaks
    (bgo#689358).
  + Add desktop background options (bgo#689299).
  + Add Pantheon to OnlyShowIn (bgo#684097).
  + Show the XKB option group description (bgo#678171).
  + Use the new laptop lid policy in xrandr (bgo#688814).
  + Several code clean ups.
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Add a Mouse group with the locate-pointer key (bgo#685620)
  + Add tweak for resize-with-right-button on Windows group
    (bgo#678648)
  + Add tweak for mouse-button-modifier on Windows group
    (bgo#678648)
  + Updated translations.
* Thu Oct  4 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Can configure extension preferences
  + Support input sources (bgo#684712)
  + Support typing options (bgo#678171)
  + Support power-button action
  + Many translation improvements (bgo#683630).
- Drop gnome-tweak-tool-pwr-button.patch: fixed upstream.
* Mon Aug 13 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Now appear as "Tweak Tool" in Activities (bgo#678778)
  + Fix incompatibility with new gnome-shell extensions (bgo678778)
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Update icon (bgo#649359)
  + Fix appearance of tweaks to no longer have a white background
  + Remove welcome image and start with a tweakgroup selected by
    default
  + Add link to extensions.gnome.org
- Changes from version 3.5.0:
  + Work with new gnome-shell DBus interface.
- Rebase gnome-tweak-tool-pwr-button.patch.
- Add hicolor-icon-theme BuildRequires and icon_theme_cache_*
  macros in post/postun.
* Wed Jul 18 2012 dimstar@opensuse.org
- Add gnome-tweak-tool-pwr-button.patch: Allow to configure what
  action should be performed when pressing the power button (acpi)
  (bnc#770048).
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 3.4.0.1:
  + Fix broken pkg-config check.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Fix user-theme shell extension support (bgo#675106)
  + Support workspaces only on primary
  + Support static workspaces
  + Add nautilus always-use-location-entry
  + Change widget for text-scaling-factor to SpinButton
    (bgo#650660)
  + Dont crash on missing schemas (bgo#647132)
  + Updated translations.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Adapt to Metacity/Mutter/Shell ported to GSettings
  + Adapt to GNOME Shell 3.4 DBus interface
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 3.2.2:
  + Dont die on malformed schemas
  + Updated translations.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Ellipsize long strings; this should fix window size issues.
  + Updated translations.
* Wed Sep 28 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Adopt GNOME version numbering
  + Rename some tweak groups, File Manager -> Desktop, etc
  + Fix build against PyGObject-3
  + Improve search results
  + Support GNOME Shell 3.2 extensions
- Change pkgconfig(pygobject-2.0) BuildRequires to
  pkgconfig(pygobject-3.0), following upstream change.
- Add python-gobject Requires as this python application obviously
  needs it.
* Fri Aug 19 2011 dimstar@opensuse.org
- Update to version 3.1.0:
  + Change tweakgroup architecture: tweaks in different files can
    appear in the same categories now.
  + Tweaks can now override summary/description usually obtained
    from gconf/gsettings
  + Move window border theme to interfaces
  + Mark many strings as translatable.
  + Now appears as 'Advanced Settings' in GNOME shell search
  + Add a -v,--verbose option that prints changed settings
  + Add a -d,--debug option
  + Add Unity to OnlyShowIn
* Wed Jun 22 2011 dimstar@opensuse.org
- Update to version 3.0.5:
  + More autostart desktop file fixes. Try harder to autostart
    nautilus when tweaking desktop handling.
  + Appearance improvements (theme install, sorted combo boxes)
  + Tweak window focus mode (focus follows mouse)
  + Tweak desktop item visibility with more control (show trash,
    show computer etc.)
  + Dont offer to restart shell multiple times when enabling
    extensions.
* Fri Jun  3 2011 dimstar@opensuse.org
- Add gobject-introspection BuildRequires to automatically get
  typelib()-style Requires.
- Drop libgtk-3-0 and gconf2 Requires. They are now added as
  typelib()-style Requires
* Sun May 22 2011 dimstar@opensuse.org
- Update to version 3.0.4:
  + bgo#648751: Support system wide themes
  + bgo#649687: Fix duplicate themes
  + A theming specification for shell themes has been developed and
    agreed upon by a number of theme authors. If installing a theme
    matching this specification, show the appropriate name.
  + Support management of Shell extensions (in home directory)
* Thu Apr 28 2011 fcrozat@novell.com
- Update to version 3.0.3:
  + bgo#648087: autostart nautilus at login if it is configured to
    show desktop icons.
  + bgo#648735: improved robustness for missing theme/icon
    directories.
  + Fix shell theme installation for themes found in the wild.
  + Improve shell theme selection.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.2:
  + Really tweak window theme - both the fallback and the shell
    metacity/mutter theme.
  + Fix attribution of data/welcome.png
- Changes from version 3.0.1:
  + Fix localization
  + Tweak window theme
  + Tweak week date in calendar
  + Tweak cursor themes
  + Support user installed themes in $HOME
  + Remove org.gnome.desktop.background draw-backgroud tweak, it
    should never be false
- Drop gnome-tweak-tool-3.0.0-fix-localization.patch: fixed
  usptream.
- Remove now unneeded calls to autoreconf and intltoolize.
* Tue Apr 26 2011 vuntz@opensuse.org
- Clean packaging for inclusion in Factory.
* Mon Apr  4 2011 lmedinas@opensuse.org
- Initial import based on spec by Michel Salim
  <salimma@fedoraproject.org>, for version 3.0.0.
- Add gnome-tweak-tool-3.0.0-fix-localization.patch: from upstream,
  fix localization issues.
